==> pegasus-2.7.0.tar.gz: pegasus/src/Providers/TestProviders/CMPI/TestFail_1/tests/TestCMPI_Fail_1.cpp <==
//%2006////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation, The Open Group.
// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; Symantec Corporation; The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//==============================================================================
//
//%/////////////////////////////////////////////////////////////////////////////

#include <Pegasus/Common/Config.h>
#include <Pegasus/Common/Constants.h>
#include <Pegasus/Common/CIMType.h>
#include <Pegasus/Common/CIMName.h>
#include <Pegasus/Common/CIMInstance.h>
#include <Pegasus/Common/CIMProperty.h>
#include <Pegasus/Common/CIMValue.h>
#include <Pegasus/Common/System.h>
#include <Pegasus/Common/InternalException.h>
#include <Pegasus/Client/CIMClient.h>

PEGASUS_USING_PEGASUS;
PEGASUS_USING_STD;


CIMNamespaceName providerNamespace;
const CIMName CLASSNAME = CIMName ("TestCMPI_Fail_1");

const String CMPI_TESTFAIL_ERROR = "CIM_ERR_FAILED: Error initializing CMPI MI"
    " TestCMPIFail_1Provider, the following MI factory function(s) returned"
    " an error: TestCMPIFail_1Provider_Create_InstanceMI;"
    " TestCMPIFail_1Provider_Create_AssociationMI;"
    " TestCMPIFail_1Provider_Create_MethodMI;"
    " TestCMPIFail_1Provider_Create_PropertyMI;"
    " TestCMPIFail_1Provider_Create_IndicationMI";

const String RCMPI_ERROR = "CIM_ERR_FAILED: ProviderInitFailure:"
    " Error initializing the API's _Create<mi-type>MI";

Boolean verbose;

void _usage ()
{
     cerr << "Usage: TestCMPI_Fail_1 {test} {namespace}" << endl;
}

void test01 (CIMClient & client)
{
    try
    {
        Array<CIMObjectPath> array = client.enumerateInstanceNames (
            providerNamespace, CLASSNAME);
        // enumerateInstanceNames should throw exception.
        PEGASUS_TEST_ASSERT(0);
    }
    catch (const CIMException &e)
    {
        if (e.getMessage() != CMPI_TESTFAIL_ERROR 
                && e.getMessage() != RCMPI_ERROR)
        {
            throw e;
        }
    }
}


void _test (CIMClient & client)
{
    try
    {
        test01 (client);
    }
    catch (Exception & e)
    {
        cerr << "test failed: " << e.getMessage () << endl;
        exit (-1);
    }
}


int main (int argc, char **argv)
{
    verbose = (getenv ("PEGASUS_TEST_VERBOSE")) ? true : false;
    CIMClient client;
    try
    {
        client.connectLocal ();
    }
    catch (Exception & e)
    {
        cerr << e.getMessage () << endl;
        return -1;
    }

    if (argc != 3)
    {
        _usage ();
        return 1;
    }
    else
    {
        const char *opt = argv[1];
        if (String::equalNoCase (opt, "test"))
        {
            providerNamespace = CIMNamespaceName (argv[2]);
            _test (client);
        }
        else
        {
            cerr << "Invalid option: " << opt << endl;
            _usage ();
            return -1;
        }
    }

    cout << argv[0] << " +++++ passed all tests" << endl;

    return 0;
}

==> pegasus-2.7.2.tar.gz: pegasus/src/Providers/TestProviders/CMPI/TestFail_1/tests/TestCMPI_Fail_1.cpp <==
//%2006////////////////////////////////////////////////////////////////////////
//
// Copyright (c) 2000, 2001, 2002 BMC Software; Hewlett-Packard Development
// Company, L.P.; IBM Corp.; The Open Group; Tivoli Systems.
// Copyright (c) 2003 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation, The Open Group.
// Copyright (c) 2004 BMC Software; Hewlett-Packard Development Company, L.P.;
// IBM Corp.; EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2005 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; VERITAS Software Corporation; The Open Group.
// Copyright (c) 2006 Hewlett-Packard Development Company, L.P.; IBM Corp.;
// EMC Corporation; Symantec Corporation; The Open Group.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// THE ABOVE COPYRIGHT NOTICE AND THIS PERMISSION NOTICE SHALL BE INCLUDED IN
// ALL COPIES OR SUBSTANTIAL PORTIONS OF THE SOFTWARE. THE SOFTWARE IS PROVIDED
// "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
// PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
// HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
// ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//
//==============================================================================
//
//%/////////////////////////////////////////////////////////////////////////////

#include <Pegasus/Common/Config.h>
#include <Pegasus/Common/Constants.h>
#include <Pegasus/Common/CIMType.h>
#include <Pegasus/Common/CIMName.h>
#include <Pegasus/Common/CIMInstance.h>
#include <Pegasus/Common/CIMProperty.h>
#include <Pegasus/Common/CIMValue.h>
#include <Pegasus/Common/System.h>
#include <Pegasus/Common/InternalException.h>
#include <Pegasus/Client/CIMClient.h>

PEGASUS_USING_PEGASUS;
PEGASUS_USING_STD;


CIMNamespaceName providerNamespace;
const CIMName CLASSNAME = CIMName ("TestCMPI_Fail_1");

const String CMPI_TESTFAIL_INST_ERROR = "CIM_ERR_FAILED: Error initializing"
    " CMPI MI TestCMPIFail_1Provider, the following MI factory function(s)"
    " returned an error: TestCMPIFail_1Provider_Create_InstanceMI";

const String CMPI_TESTFAIL_METH_ERROR = "CIM_ERR_FAILED: Error initializing"
    " CMPI MI TestCMPIFail_1Provider, the following MI factory function(s)"
    " returned an error: TestCMPIFail_1Provider_Create_MethodMI";

const String CMPI_TESTFAIL_ASSOC_ERROR = "CIM_ERR_FAILED: Error initializing"
    " CMPI MI TestCMPIFail_1Provider, the following MI factory function(s)"
    " returned an error: TestCMPIFail_1Provider_Create_AssociationMI";

const String RCMPI_ERROR = "CIM_ERR_FAILED: ProviderInitFailure:"
    " Error initializing the API's _Create<mi-type>MI";

Boolean verbose;

void _usage ()
{
     cerr << "Usage: TestCMPI_Fail_1 {test} {namespace}" << endl;
}

void test01 (CIMClient & client)
{
    try
    {
        Array<CIMObjectPath> array = client.enumerateInstanceNames (
            providerNamespace, CLASSNAME);
        // enumerateInstanceNames should throw exception.
        PEGASUS_TEST_ASSERT(0);
    }
    catch (const CIMException &e)
    {
        if (e.getMessage() != CMPI_TESTFAIL_INST_ERROR 
                && e.getMessage() != RCMPI_ERROR)
        {
            throw e;
        }
    }
}

void test02 (CIMClient & client)
{
    try
    {
        CIMObjectPath instanceName(
            String::EMPTY,
            providerNamespace, 
            CLASSNAME,
            Array<CIMKeyBinding>());

        Array<CIMParamValue> outParams;

        CIMValue value = client.invokeMethod(
             providerNamespace,
             instanceName,
             "foo",
             Array<CIMParamValue>(),
             outParams);
    }
    catch (const CIMException &e)
    {
        if (e.getMessage() != CMPI_TESTFAIL_METH_ERROR 
                && e.getMessage() != RCMPI_ERROR)
        {
            throw e;
        }
    }
}

void test03 (CIMClient & client)
{
    try
    {
        CIMObjectPath instanceName(
            String::EMPTY,
            providerNamespace, 
            CLASSNAME,
            Array<CIMKeyBinding>());

        Array<CIMObjectPath> result = client.associatorNames(
            providerNamespace,
            instanceName);
    }
    catch (const CIMException &e)
    {
        if (e.getMessage() != CMPI_TESTFAIL_ASSOC_ERROR 
                && e.getMessage() != RCMPI_ERROR)
        {
            throw e;
        }
    }
}

void _test (CIMClient & client)
{
    try
    {
        test01 (client);
        test02 (client);
        test03 (client);
    }
    catch (Exception & e)
    {
        cerr << "test failed: " << e.getMessage () << endl;
        exit (-1);
    }
}


int main (int argc, char **argv)
{
    verbose = (getenv ("PEGASUS_TEST_VERBOSE")) ? true : false;
    CIMClient client;
    try
    {
        client.connectLocal ();
    }
    catch (Exception & e)
    {
        cerr << e.getMessage () << endl;
        return -1;
    }

    if (argc != 3)
    {
        _usage ();
        return 1;
    }
    else
    {
        const char *opt = argv[1];
        if (String::equalNoCase (opt, "test"))
        {
            providerNamespace = CIMNamespaceName (argv[2]);
            _test (client);
        }
        else
        {
            cerr << "Invalid option: " << opt << endl;
            _usage ();
            return -1;
        }
    }

    cout << argv[0] << " +++++ passed all tests" << endl;

    return 0;
}
